<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Spėti</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Rasta</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normali</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Didelė</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Praleista</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Žaidimas baigtas</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 iš %n taško</numerusform>
            <numerusform>%1 iš %n taškų</numerusform>
            <numerusform>%1 iš %n taškų</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 iš %n taško</numerusform>
            <numerusform>3 iš %n taškų</numerusform>
            <numerusform>3 iš %n taškų</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 iš %n taško</numerusform>
            <numerusform>2 iš %n taškų</numerusform>
            <numerusform>2 iš %n taškų</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 iš %n taško</numerusform>
            <numerusform>1 iš %n taškų</numerusform>
            <numerusform>1 iš %n taškų</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 iš %n taško</numerusform>
            <numerusform>0 iš %n taškų</numerusform>
            <numerusform>0 iš %n taškų</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n taškas</numerusform>
            <numerusform>%n taškai</numerusform>
            <numerusform>%n taškų</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Maksimalus taškų skaičius buvo paskaičiuotas iš šių trisdešimties žodžių:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n spėjimas</numerusform>
            <numerusform>%n spėjimai</numerusform>
            <numerusform>%n spėjimų</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n išbraukimas</numerusform>
            <numerusform>%n išbraukimai</numerusform>
            <numerusform>%n išbraukimų</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Klasikinis</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Pasipildymo</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Ištvermės</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Išbraukimo</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Paskirstymo</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Disciplinos</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Skaičiuoja atvirkštine tvarka 30 sekundžių, esant teisingiems spėjimams - pridedamas laikas.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Skaičiuoja atvirkštine tvarka 3 minutes.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Skaičiuoja atvirkštine tvarka 30 sekundžių, esant teisingiems spėjimams - laikas atstatomas.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Skaičiuoja atvirkštine tvarka 45 sekundes, esant teisingiems spėjimams - laikas trumpam pristabdomas.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Žaidimas pasibaigia po 3 neteisingų spėjimų.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Žaidimas pasibaigia po 30 spėjimų.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Skaičiuoja atvirkštine tvarka 30 sekundžių, priklausomai nuo spėjimų, laikas pridedamas arba atimamas.</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Neribotas</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation>Žaidimas baigiasi, kai yra surasti visi žodžiai.</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Nepavyko iš failo perskaityti kauliuko.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Nepavyko iš failo perskaityti žodžių sąrašo.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Plokštės kalba</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Tinkinta</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Pasirinkti...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Pastaba:&lt;/b&gt; Šie pakeitimai įsigalios, kai pradėsite naują žaidimą.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Kalba:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Kauliukas:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Žodžių sąrašas:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Žodynas:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Pasirinkite kauliuko failą</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Pasirinkite žodžių sąrašo failą</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalba:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Naujas žaidimas</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Žodžių kiekis:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Minimalus žodžio ilgis:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Mažas</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Vidutinis</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Didelis</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Atsitiktinis</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n raidė</numerusform>
            <numerusform>%n raidės</numerusform>
            <numerusform>%n raidžių</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Rekordai</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Vardas</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Surinkta taškų</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Rangas</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation>Daugiausia</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Sveikiname!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Jūs sumušėte savo rekordą!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Puikiai padirbėta!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Jūs pasiekėte naują rekordą!</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Nepasiekiama</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Pauzė&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Spustelėkite, norėdami tęsti žaidimą.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Prašome palaukti&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Įkeliamas žaidimas...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Spustelėkite, norėdami pradėti naują žaidimą.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Prašome palaukti&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Kuriama nauja plokštė...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Prašome palaukti&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizuojamas žodžių sąrašas...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>&amp;Naujas žaidimas</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>Naujas &amp;metimas</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Pasirinkti...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>Da&amp;lintis...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Užbaigti</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pau&amp;zė</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Išsamiau</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Rekordai</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Baigti</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Rodyti &amp;maksimalų taškų skaičių</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Niekada</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>Žaidimo &amp;pabaigoje</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>Vis&amp;ada</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Rodyti pra&amp;leistus žodžius</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Rodyti žodžių &amp;skaičiuoklę</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>Plo&amp;kštės kalba...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programos ka&amp;lba...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Valdymas</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Autorių Teisės &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt; žaidimo variantas vienam žaidėjui</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Žodžių sąrašas anglų kalba yra paremtas &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; pagal Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Žodžių sąrašas hebrajų kalba yra paremtas &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; pagal Nadav Har&apos;El ir Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Importuoti žaidimą</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Tanglet žaidimai (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nepavyko pradėti užklausto žaidimo.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Eksportuoti žaidimą</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Užbaigti dabartinį žaidimą?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Plokštės dydis:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normali</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Didelė</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Žodžių tankumas:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Žodžių ilgis:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 ar daugiau raidžių</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Žaidimo tipas:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Aprašas:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Valdymas</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Žaidimas pele:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pasirinkti žodį:&lt;/b&gt; Spustelėti ant žodžio raidžių.&lt;br&gt;&lt;b&gt;Spėti:&lt;/b&gt; Spustelėti ant paskutinės pasirinktos raidės.&lt;br&gt;&lt;b&gt;Ištrinti raides:&lt;/b&gt; Spustelėti ant anksčiau pasirinktos raidės.&lt;br&gt;&lt;b&gt;Išvalyti žodį:&lt;/b&gt; Du kartus spustelėti ant pirmos pasirinktos raidės.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Žaidimas klaviatūra:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pasirinkti žodį:&lt;/b&gt; Rinkti žodžio raides.&lt;br&gt;&lt;b&gt;Spėti:&lt;/b&gt; Spausti įvedimo (Enter) klavišą.&lt;br&gt;&lt;b&gt;Išvalyti žodį:&lt;/b&gt; Spausti Valdymo+Naikinimo (Ctrl+Backspace) klavišą.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Raidės:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Rasta:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n taškas</numerusform>
            <numerusform>%n taškai</numerusform>
            <numerusform>%n taškų</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Žodžių ieškojimo žaidimas</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Norimas žaisti žaidimo failas.</translation>
    </message>
</context>
</TS>
